# Generated by Django 4.2.3 on 2023-08-08 02:41

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0096_rename_external_remittance_healtheconomicsincome_external_remit_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="external_remit_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="interest_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="internal_remit_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="more_sources_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="ngo_assistance_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="pension_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="rental_income_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="selling_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="wages_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="external_remit_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="interest_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="internal_remit_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="more_sources_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="ngo_assistance_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="pension_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="rental_income_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="selling_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="wages_value",
            field=models.IntegerField(
                blank=True,
                help_text="Use cash equivalent in local currency",
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(999999999),
                ],
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
    ]



# Generated by Django 4.2.1 on 2023-05-24 17:51

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0048_alter_healtheconomicsincome_external_remittance_currency_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="external_remittance_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="external_remittance_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="financial_status",
            field=models.CharField(
                choices=[
                    ("1", "Very good"),
                    ("2", "Good"),
                    ("3", "Moderate"),
                    ("4", "Bad"),
                    ("5", "Very bad"),
                    ("DWTA", "Don’t want to answer"),
                ],
                max_length=25,
                verbose_name="Would you say your household's financial situation is?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="financial_status_compare",
            field=models.CharField(
                choices=[
                    ("1", "Among most wealthy"),
                    ("2", "Above average "),
                    ("3", "Average wealth"),
                    ("4", "Below average"),
                    ("5", "Among least wealthy"),
                    ("DWTA", "Don’t want to answer"),
                ],
                max_length=25,
                verbose_name="How would you rate your household’s financial situation compared with others in your community?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="interest_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="interest_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="internal_remittance_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="internal_remittance_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="more_sources_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="more_sources_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="ngo_assistance_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="ngo_assistance_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="pension_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="pension_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="rental_income_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="rental_income_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="selling_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="selling_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="wages",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Do not know"),
                    ("DWTA", "Don't want to answer"),
                ],
                help_text=None,
                max_length=15,
                verbose_name="Income from wages, salary from job",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="wages_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicsincome",
            name="wages_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="external_remittance_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="external_remittance_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="financial_status",
            field=models.CharField(
                choices=[
                    ("1", "Very good"),
                    ("2", "Good"),
                    ("3", "Moderate"),
                    ("4", "Bad"),
                    ("5", "Very bad"),
                    ("DWTA", "Don’t want to answer"),
                ],
                max_length=25,
                verbose_name="Would you say your household's financial situation is?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="financial_status_compare",
            field=models.CharField(
                choices=[
                    ("1", "Among most wealthy"),
                    ("2", "Above average "),
                    ("3", "Average wealth"),
                    ("4", "Below average"),
                    ("5", "Among least wealthy"),
                    ("DWTA", "Don’t want to answer"),
                ],
                max_length=25,
                verbose_name="How would you rate your household’s financial situation compared with others in your community?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="interest_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="interest_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="internal_remittance_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="internal_remittance_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="more_sources_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="more_sources_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="ngo_assistance_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="ngo_assistance_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="pension_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="pension_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="rental_income_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="rental_income_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="selling_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="selling_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="wages",
            field=models.CharField(
                choices=[
                    ("Yes", "Yes"),
                    ("No", "No"),
                    ("dont_know", "Do not know"),
                    ("DWTA", "Don't want to answer"),
                ],
                help_text=None,
                max_length=15,
                verbose_name="Income from wages, salary from job",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="wages_value",
            field=models.IntegerField(
                blank=True,
                null=True,
                verbose_name="Estimated <u>total amount of income</u> from this source over the time period from above",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicsincome",
            name="wages_value_known",
            field=models.CharField(
                choices=[
                    ("weekly", "as weekly income"),
                    ("monthly", "as monthly income"),
                    ("yearly", "as yearly income"),
                    ("dont_know", "Don’t know"),
                    ("DWTA", "Don’t want to answer"),
                    ("N/A", "Not applicable"),
                ],
                default="N/A",
                max_length=15,
                verbose_name="Over which <u>time period</u> are you able to estimate?",
            ),
        ),
    ]



# Generated by Django 4.2.3 on 2023-08-03 15:57

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0085_alter_healtheconomicsassets_external_wall_material_and_more",
        ),
    ]

    operations = [
        migrations.RenameField(
            model_name="healtheconomicshouseholdhead",
            old_name="hoh_employment",
            new_name="hoh_employment_status",
        ),
        migrations.RenameField(
            model_name="healtheconomicspatient",
            old_name="pat_employment",
            new_name="pat_employment_status",
        ),
        migrations.RenameField(
            model_name="historicalhealtheconomicshouseholdhead",
            old_name="hoh_employment",
            new_name="hoh_employment_status",
        ),
        migrations.RenameField(
            model_name="historicalhealtheconomicspatient",
            old_name="pat_employment",
            new_name="pat_employment_status",
        ),
    ]



# Generated by Django 4.2.3 on 2023-07-25 18:31

import uuid

import _socket
import django.core.validators
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_revision.revision_field
import edc_facility.model_mixins
import edc_model_fields.fields.other_charfield
import edc_sites.models
import edc_utils.date
import simple_history.models
from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):
    initial = True

    dependencies = [
        ("sites", "0002_alter_domain_unique"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("edc_facility", "0006_alter_healthfacility_health_facility_type"),
    ]

    operations = [
        migrations.CreateModel(
            name="HistoricalHealthFacility",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(default=edc_utils.date.get_utcnow),
                ),
                ("name", models.CharField(db_index=True, max_length=25)),
                (
                    "health_facility_type_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "gps",
                    models.CharField(
                        blank=True,
                        help_text="copy and paste directly from google maps",
                        max_length=50,
                        null=True,
                    ),
                ),
                (
                    "latitude",
                    models.FloatField(
                        blank=True,
                        help_text="in degrees. copy and paste directly from google maps",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(-90),
                            django.core.validators.MaxValueValidator(90),
                        ],
                    ),
                ),
                (
                    "longitude",
                    models.FloatField(
                        blank=True,
                        help_text="in degrees. copy and paste directly from google maps",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(-180),
                            django.core.validators.MaxValueValidator(180),
                        ],
                    ),
                ),
                ("mon", models.BooleanField()),
                ("tue", models.BooleanField()),
                ("wed", models.BooleanField()),
                ("thu", models.BooleanField()),
                ("fri", models.BooleanField()),
                ("sat", models.BooleanField()),
                ("sun", models.BooleanField()),
                ("notes", models.TextField(blank=True, null=True)),
                (
                    "distance",
                    models.IntegerField(
                        help_text="In km. If within the integrated-care clinic facility type '0'",
                        verbose_name="Approximate distance from integrated-care clinic",
                    ),
                ),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4,
                        editable=False,
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                ("history_date", models.DateTimeField(db_index=True)),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "health_facility_type",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="edc_facility.healthfacilitytypes",
                        verbose_name="Health facility type",
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical Health Facility",
                "verbose_name_plural": "historical Health Facilities",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": ("history_date", "history_id"),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name="HealthFacility",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True,
                        default=django_audit_fields.models.audit_model_mixin.utcnow,
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(default=edc_utils.date.get_utcnow),
                ),
                ("name", models.CharField(max_length=25, unique=True)),
                (
                    "health_facility_type_other",
                    edc_model_fields.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "gps",
                    models.CharField(
                        blank=True,
                        help_text="copy and paste directly from google maps",
                        max_length=50,
                        null=True,
                    ),
                ),
                (
                    "latitude",
                    models.FloatField(
                        blank=True,
                        help_text="in degrees. copy and paste directly from google maps",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(-90),
                            django.core.validators.MaxValueValidator(90),
                        ],
                    ),
                ),
                (
                    "longitude",
                    models.FloatField(
                        blank=True,
                        help_text="in degrees. copy and paste directly from google maps",
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(-180),
                            django.core.validators.MaxValueValidator(180),
                        ],
                    ),
                ),
                ("mon", models.BooleanField()),
                ("tue", models.BooleanField()),
                ("wed", models.BooleanField()),
                ("thu", models.BooleanField()),
                ("fri", models.BooleanField()),
                ("sat", models.BooleanField()),
                ("sun", models.BooleanField()),
                ("notes", models.TextField(blank=True, null=True)),
                (
                    "distance",
                    models.IntegerField(
                        help_text="In km. If within the integrated-care clinic facility type '0'",
                        verbose_name="Approximate distance from integrated-care clinic",
                    ),
                ),
                (
                    "health_facility_type",
                    models.ForeignKey(
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="edc_facility.healthfacilitytypes",
                        verbose_name="Health facility type",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
            ],
            options={
                "verbose_name": "Health Facility",
                "verbose_name_plural": "Health Facilities",
                "ordering": ("-modified", "-created"),
                "get_latest_by": "modified",
                "abstract": False,
                "default_permissions": (
                    "add",
                    "change",
                    "delete",
                    "view",
                    "export",
                    "import",
                ),
                "default_manager_name": "objects",
            },
            managers=[
                ("objects", edc_facility.model_mixins.Manager()),
                ("on_site", edc_sites.models.CurrentSiteManager()),
            ],
        ),
    ]



# Generated by Django 4.2.3 on 2023-08-10 03:23

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0098_alter_healtheconomicshouseholdhead_hoh_and_more"),
    ]

    operations = [
        migrations.RemoveField(
            model_name="healtheconomicspatient",
            name="pat_citizen",
        ),
        migrations.RemoveField(
            model_name="historicalhealtheconomicspatient",
            name="pat_citizen",
        ),
    ]



# Generated by Django 5.0.4 on 2024-04-16 13:32

import edc_model_fields.fields.custom_django_fields
import intecomm_subject.models.fields.expense_field
from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_subject", "0172_alter_careseekingb_inpatient_cost_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="historicalcareseekinga",
            name="accompany",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("alone", "No one, I came alone"),
                    ("main_earner", "Main household earner"),
                    ("adult", "Other family member/relatives/friends (adults)"),
                    ("child", "Other family member/relatives/friends (children)"),
                ],
                max_length=25,
                metadata="FACMP1",
                null=True,
                verbose_name="Who accompanied you here today?",
            ),
        ),
        migrations.RemoveField(
            model_name="careseekinga",
            name="accompany",
        ),
        migrations.AlterField(
            model_name="careseekinga",
            name="travel_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FTRAVCOST1",
                null=True,
                verbose_name="Thinking about yourself and anyone that accompanied you, how much was spent on travel from your home to reach here?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalcareseekinga",
            name="travel_cost",
            field=intecomm_subject.models.fields.expense_field.ExpenseField(
                metadata="FTRAVCOST1",
                null=True,
                verbose_name="Thinking about yourself and anyone that accompanied you, how much was spent on travel from your home to reach here?",
            ),
        ),
        migrations.AddField(
            model_name="careseekinga",
            name="accompany",
            field=edc_model_fields.fields.custom_django_fields.CharField2(
                choices=[
                    ("alone", "No one, I came alone"),
                    ("main_earner", "Main household earner"),
                    ("adult", "Other family member/relatives/friends (adults)"),
                    ("child", "Other family member/relatives/friends (children)"),
                ],
                max_length=25,
                metadata="FACMP1",
                null=True,
                verbose_name="Who accompanied you here today?",
            ),
        ),
    ]



# Generated by Django 4.2.3 on 2023-07-26 17:30
from django.db import migrations
from edc_list_data import PreloadData
from tqdm import tqdm

from intecomm_facility.list_data import list_data


def update_healthfacility(apps, schema_editor):
    healthfacility_old_model_cls = apps.get_model("intecomm_screening", "oldhealthfacility")
    healthfacility_model_cls = apps.get_model("intecomm_facility", "healthfacility")
    healthfacilitytype_old_model_cls = apps.get_model("intecomm_lists", "healthfacilitytypes")
    healthfacilitytype_model_cls = apps.get_model("edc_facility", "healthfacilitytypes")

    PreloadData(list_data=list_data, apps=apps)

    # populate new health facility model
    total = healthfacility_old_model_cls.objects.all().count()
    print("\n")
    for obj_old in tqdm(healthfacility_old_model_cls.objects.all(), total=total):
        obj_new = healthfacility_model_cls()
        for fld in healthfacility_model_cls._meta.get_fields():
            if fld.name in ["nextappointment", "healthtalklog"]:
                continue
            fldname = fld.name
            if fld.name == "sun":
                setattr(obj_new, fldname, False)
            else:
                try:
                    value = getattr(obj_old, f"{fld.name}_id")
                except AttributeError:
                    value = getattr(obj_old, fld.name)
                else:
                    if fld.name == "health_facility_type":
                        old_name = healthfacilitytype_old_model_cls.objects.get(
                            id=getattr(obj_old, f"{fld.name}_id")
                        ).name
                        value = healthfacilitytype_model_cls.objects.get(name=old_name).id
                    fldname = f"{fld.name}_id"
                setattr(obj_new, fldname, value)
        obj_new.save()


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_facility", "0002_alter_healthfacility_device_created_and_more"),
        ("intecomm_screening", "0045_alter_consentrefusal_options_and_more"),
    ]

    operations = [migrations.RunPython(update_healthfacility)]



from django.db import models
from edc_constants.choices import YES_NO_NA
from edc_constants.constants import NOT_APPLICABLE
from edc_model.models import BaseUuidModel, OtherCharField

from intecomm_lists.models import HtnManagement

from ..choices import HTN_MANAGEMENT
from ..model_mixins import CrfModelMixin, FollowupReviewModelMixin


class HtnReview(FollowupReviewModelMixin, CrfModelMixin, BaseUuidModel):
    test_date = models.DateField(
        verbose_name="Date tested for Hypertension",
        null=True,
        blank=True,
        editable=False,
        help_text="",
    )

    dx = models.CharField(
        verbose_name="Has the patient been diagnosed with Hypertension?",
        max_length=15,
        choices=YES_NO_NA,
        default=NOT_APPLICABLE,
    )

    managed_by = models.ManyToManyField(
        HtnManagement,
        verbose_name="How will the patient's hypertension be managed going forward?",
    )

    managed_by_other = OtherCharField()

    managed_by_old = models.CharField(
        verbose_name="How will the patient's hypertension be managed going forward?",
        max_length=25,
        choices=HTN_MANAGEMENT,
        default=NOT_APPLICABLE,
    )

    care_start_date = models.DateField(
        verbose_name="Date clinical management started",
        null=True,
        blank=True,
    )

    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "Hypertension Review"
        verbose_name_plural = "Hypertension Review"
        indexes = CrfModelMixin.Meta.indexes + BaseUuidModel.Meta.indexes



from django import forms
from edc_crf.modelform_mixins import CrfModelFormMixin
from intecomm_form_validators.subject.clinical_review_form_validator import (
    ClinicalReviewFormValidator,
)

from ..models import ClinicalReview


class ClinicalReviewForm(CrfModelFormMixin, forms.ModelForm):
    form_validator_cls = ClinicalReviewFormValidator

    class Meta:
        model = ClinicalReview
        fields = "__all__"



from django.db import models
from django_db_views.db_view import DBView
from edc_qareports.model_mixins import QaReportModelMixin

from .view_definition import get_view_definition


class SubjectsTransferred(QaReportModelMixin, DBView):

    consented = models.DateField()
    visit_code = models.CharField(max_length=100)
    last_visit = models.DateField(null=True, blank=True)
    transferred = models.DateField(null=True, blank=True)
    months = models.IntegerField(null=True, blank=True)
    offstudy = models.DateField(null=True, blank=True)
    last_seen = models.DateField(null=True, blank=True)

    view_definition = get_view_definition()

    class Meta:
        managed = False
        db_table = "subjects_transferred_view"
        verbose_name = "Subjects Transferred"
        verbose_name_plural = "Subjects Transferred"



# Generated by Django 4.1.7 on 2023-03-31 18:33

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0016_remove_clinicalreview_reason_other_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="bloodresultsfbc",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsglu",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultshba1c",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsins",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslipid",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultsrft",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="dminitialreview",
            name="glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("N/A", ""),
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Glucose quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="dmreview",
            name="glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("N/A", ""),
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Glucose quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="glucose",
            name="glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("N/A", ""),
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Glucose quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsglu",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultshba1c",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsins",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslipid",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsrft",
            name="results_abnormal",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No")],
                help_text="Abnormal results present at baseline or continuing from baseline not included.",
                max_length=25,
                verbose_name="Are any of the above results abnormal?",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldminitialreview",
            name="glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("N/A", ""),
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Glucose quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldmreview",
            name="glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("N/A", ""),
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Glucose quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalglucose",
            name="glucose_quantifier",
            field=models.CharField(
                choices=[
                    ("N/A", ""),
                    ("=", "="),
                    (">", ">"),
                    (">=", ">="),
                    ("<", "<"),
                    ("<=", "<="),
                ],
                default="N/A",
                max_length=10,
                verbose_name="Glucose quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhivinitialreview",
            name="vl_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("N/A", "Not applicable"), ("=", "="), (">", ">"), ("<", "<")],
                max_length=10,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="historicalviralloadresult",
            name="vl_quantifier",
            field=models.CharField(
                choices=[("N/A", "Not applicable"), ("=", "="), (">", ">"), ("<", "<")],
                default="=",
                max_length=10,
                verbose_name="Quantifier",
            ),
        ),
        migrations.AlterField(
            model_name="hivinitialreview",
            name="vl_quantifier",
            field=models.CharField(
                blank=True,
                choices=[("N/A", "Not applicable"), ("=", "="), (">", ">"), ("<", "<")],
                max_length=10,
                null=True,
            ),
        ),
        migrations.AlterField(
            model_name="viralloadresult",
            name="vl_quantifier",
            field=models.CharField(
                choices=[("N/A", "Not applicable"), ("=", "="), (">", ">"), ("<", "<")],
                default="=",
                max_length=10,
                verbose_name="Quantifier",
            ),
        ),
    ]



# Generated by Django 4.2.11 on 2024-06-20 19:38

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_subject", "0187_alter_dmreview_glucose_fasting_and_more"),
    ]

    operations = [
        migrations.DeleteModel(
            name="Diagnoses",
        ),
    ]



from django.test import TestCase
from edc_auth.auth_updater.group_updater import GroupUpdater, PermissionsCodenameError

from intecomm_auth.auth_objects import clinic_codenames, screening_codenames


class TestAuths(TestCase):
    def test_auth(self):
        group_updater = GroupUpdater(groups={})
        for codename in clinic_codenames:
            try:
                group_updater.get_from_dotted_codename(codename)
            except PermissionsCodenameError as e:
                self.fail(f"PermissionsCodenameError raised unexpectedly. Got {e}")
        for codename in screening_codenames:
            try:
                group_updater.get_from_dotted_codename(codename)
            except PermissionsCodenameError as e:
                self.fail(f"PermissionsCodenameError raised unexpectedly. Got {e}")



from django.db import models
from edc_constants.choices import PRESENT_ABSENT_NA, YES_NO
from edc_constants.constants import NOT_APPLICABLE
from edc_model.models import BaseUuidModel

from ..model_mixins import CrfModelMixin


class UrineDipstickTest(CrfModelMixin, BaseUuidModel):
    performed = models.CharField(
        verbose_name="Was the urine dipstick test performed?",
        max_length=15,
        choices=YES_NO,
    )

    not_performed_reason = models.CharField(
        verbose_name="If NO, provide reason", max_length=150, null=True, blank=True
    )

    ketones = models.CharField(
        verbose_name="Ketones?",
        max_length=25,
        choices=PRESENT_ABSENT_NA,
        default=NOT_APPLICABLE,
    )

    protein = models.CharField(
        verbose_name="Protein?",
        max_length=25,
        choices=PRESENT_ABSENT_NA,
        default=NOT_APPLICABLE,
    )

    glucose = models.CharField(
        verbose_name="Glucose?",
        max_length=25,
        choices=PRESENT_ABSENT_NA,
        default=NOT_APPLICABLE,
    )

    class Meta(CrfModelMixin.Meta, BaseUuidModel.Meta):
        verbose_name = "Urine dipstick test"
        verbose_name_plural = "Urine dipstick tests"
        indexes = CrfModelMixin.Meta.indexes + BaseUuidModel.Meta.indexes



# Generated by Django 4.1.7 on 2023-05-01 23:49
from django.db import migrations
from django.db.migrations import RunPython
from tqdm import tqdm

from ..identifiers import PatientLogIdentifier


def update_patient_log_identifier(apps, schema_editor):
    patientlog_cls = apps.get_model("intecomm_screening", "patientlog")
    total = patientlog_cls.objects.filter(filing_identifier__isnull=True).count()
    for obj in tqdm(
        patientlog_cls.objects.all(),
        total=total,
    ):
        obj.patient_log_identifier = PatientLogIdentifier(site_id=obj.site_id).identifier
        obj.save_base(update_fields=["patient_log_identifier"])


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_screening", "0023_auto_20230501_2208"),
    ]

    operations = [RunPython(update_patient_log_identifier)]



# Generated by Django 4.2.7 on 2023-12-07 01:01

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        (
            "intecomm_subject",
            "0136_subjectvisit_intecomm_su_modifie_dab86a_idx_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="bloodresultsfbc",
            name="platelets_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=0,
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(9999),
                ],
                verbose_name="Platelets",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="ast_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=0,
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(9999),
                ],
                verbose_name="AST",
            ),
        ),
        migrations.AlterField(
            model_name="bloodresultslft",
            name="ggt_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=0,
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(9999),
                ],
                verbose_name="GGT",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultsfbc",
            name="platelets_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=0,
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(9999),
                ],
                verbose_name="Platelets",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="ast_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=0,
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(9999),
                ],
                verbose_name="AST",
            ),
        ),
        migrations.AlterField(
            model_name="historicalbloodresultslft",
            name="ggt_value",
            field=models.DecimalField(
                blank=True,
                decimal_places=0,
                max_digits=8,
                null=True,
                validators=[
                    django.core.validators.MinValueValidator(1),
                    django.core.validators.MaxValueValidator(9999),
                ],
                verbose_name="GGT",
            ),
        ),
    ]



from edc_dx_review.utils import raise_if_clinical_review_does_not_exist
from edc_he.forms import (
    HealthEconomicsModelFormMixin as BaseHealthEconomicsModelFormMixin,
)


class HealthEconomicsModelFormMixin(BaseHealthEconomicsModelFormMixin):
    def clean(self) -> dict:
        cleaned_data = super().clean()
        raise_if_clinical_review_does_not_exist(cleaned_data.get("subject_visit"))
        return cleaned_data



# Generated by Django 4.2.7 on 2023-11-13 15:23

from django.db import migrations, models
import edc_model.validators.date
import edc_protocol.validators


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_ae", "0009_alter_aefollowup_device_created_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="deathreport",
            name="death_date",
            field=models.DateField(
                null=True,
                validators=[
                    edc_protocol.validators.date_not_before_study_start,
                    edc_model.validators.date.date_not_future,
                ],
                verbose_name="Date of Death",
            ),
        ),
        migrations.AlterField(
            model_name="deathreport",
            name="death_datetime",
            field=models.DateTimeField(
                null=True,
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Date and Time of Death",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldeathreport",
            name="death_date",
            field=models.DateField(
                null=True,
                validators=[
                    edc_protocol.validators.date_not_before_study_start,
                    edc_model.validators.date.date_not_future,
                ],
                verbose_name="Date of Death",
            ),
        ),
        migrations.AlterField(
            model_name="historicaldeathreport",
            name="death_datetime",
            field=models.DateTimeField(
                null=True,
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Date and Time of Death",
            ),
        ),
    ]



from django.contrib import admin

from ..admin_site import intecomm_subject_admin
from ..forms import HtnMedicationAdherenceForm
from ..models import HtnMedicationAdherence
from .modeladmin_mixins import CrfModelAdmin, MedicationAdherenceAdminMixin


@admin.register(HtnMedicationAdherence, site=intecomm_subject_admin)
class HtnMedicationAdherenceAdmin(MedicationAdherenceAdminMixin, CrfModelAdmin):
    form = HtnMedicationAdherenceForm



# Generated by Django 4.1.2 on 2022-11-29 05:12

from django.db import migrations


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_lists", "0001_initial"),
    ]

    operations = [
        migrations.DeleteModel(
            name="ReasonsForTesting",
        ),
        migrations.DeleteModel(
            name="RxModificationReasons",
        ),
        migrations.DeleteModel(
            name="RxModifications",
        ),
    ]



from django.contrib import admin
from django_audit_fields import audit_fieldset_tuple
from edc_crf.admin import crf_status_fieldset_tuple
from edc_model_admin.mixins import InlineHideOriginalObjectNameMixin, TabularInlineMixin
from edc_rx.modeladmin_mixins import DrugRefillAdminMixin, DrugSupplyInlineMixin

from ..admin_site import intecomm_subject_admin
from ..forms import DrugRefillHivForm, DrugSupplyHivForm
from ..models import DrugRefillHiv, DrugSupplyHiv
from .modeladmin_mixins import CrfModelAdmin


class DrugSupplyHivInline(DrugSupplyInlineMixin, TabularInlineMixin, admin.TabularInline):
    model = DrugSupplyHiv
    form = DrugSupplyHivForm


@admin.register(DrugRefillHiv, site=intecomm_subject_admin)
class DrugRefillHivAdmin(
    DrugRefillAdminMixin,
    InlineHideOriginalObjectNameMixin,
    CrfModelAdmin,
):
    form = DrugRefillHivForm
    autocomplete_fields = ["rx"]

    fieldsets = (
        (None, {"fields": ("subject_visit", "report_datetime")}),
        (
            "Refill Information",
            {
                "fields": (
                    "rx",
                    "rx_other",
                    "rx_modified",
                    "modifications",
                    "modifications_other",
                    "modifications_reason",
                    "modifications_reason_other",
                )
            },
        ),
        (
            "Drug Supply: HIV",
            {
                "fields": (
                    "rx_days",
                    "clinic_days",
                    "club_days",
                    "purchased_days",
                )
            },
        ),
        crf_status_fieldset_tuple,
        audit_fieldset_tuple,
    )

    filter_horizontal = ["modifications", "modifications_reason"]



# Generated by Django 4.2.3 on 2023-08-03 03:32

import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ("intecomm_subject", "0076_healtheconomicshouseholdhead_hoh_religion_old_and_more"),
    ]

    operations = [
        migrations.AddField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_religion",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_he.religions",
                verbose_name="How would you describe the household head’s religious orientation?",
            ),
        ),
        migrations.AddField(
            model_name="healtheconomicspatient",
            name="pat_religion",
            field=models.ForeignKey(
                null=True,
                on_delete=django.db.models.deletion.PROTECT,
                to="edc_he.religions",
                verbose_name="How would you describe your religious orientation?",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_religion",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_he.religions",
                verbose_name="How would you describe the household head’s religious orientation?",
            ),
        ),
        migrations.AddField(
            model_name="historicalhealtheconomicspatient",
            name="pat_religion",
            field=models.ForeignKey(
                blank=True,
                db_constraint=False,
                null=True,
                on_delete=django.db.models.deletion.DO_NOTHING,
                related_name="+",
                to="edc_he.religions",
                verbose_name="How would you describe your religious orientation?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicshouseholdhead",
            name="hoh_religion_old",
            field=models.CharField(
                choices=[
                    ("Catholic", "Catholic"),
                    ("Protestant", "Protestant"),
                    ("Muslim", "Muslim"),
                    ("Pentecostal", "Pentecostal"),
                    ("Seventh day Adventist", "Seventh day Adventist"),
                    ("No religion", "No religion"),
                    ("OTHER", "Other, specify ..."),
                ],
                max_length=25,
                verbose_name="How would you describe the household head’s religious orientation?",
            ),
        ),
        migrations.AlterField(
            model_name="healtheconomicspatient",
            name="pat_religion_old",
            field=models.CharField(
                choices=[
                    ("Catholic", "Catholic"),
                    ("Protestant", "Protestant"),
                    ("Muslim", "Muslim"),
                    ("Pentecostal", "Pentecostal"),
                    ("Seventh day Adventist", "Seventh day Adventist"),
                    ("No religion", "No religion"),
                    ("OTHER", "Other, specify ..."),
                ],
                max_length=25,
                verbose_name="How would you describe your religious orientation?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicshouseholdhead",
            name="hoh_religion_old",
            field=models.CharField(
                choices=[
                    ("Catholic", "Catholic"),
                    ("Protestant", "Protestant"),
                    ("Muslim", "Muslim"),
                    ("Pentecostal", "Pentecostal"),
                    ("Seventh day Adventist", "Seventh day Adventist"),
                    ("No religion", "No religion"),
                    ("OTHER", "Other, specify ..."),
                ],
                max_length=25,
                verbose_name="How would you describe the household head’s religious orientation?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalhealtheconomicspatient",
            name="pat_religion_old",
            field=models.CharField(
                choices=[
                    ("Catholic", "Catholic"),
                    ("Protestant", "Protestant"),
                    ("Muslim", "Muslim"),
                    ("Pentecostal", "Pentecostal"),
                    ("Seventh day Adventist", "Seventh day Adventist"),
                    ("No religion", "No religion"),
                    ("OTHER", "Other, specify ..."),
                ],
                max_length=25,
                verbose_name="How would you describe your religious orientation?",
            ),
        ),
    ]



# Generated by Django 4.1.2 on 2022-12-05 14:57

import _socket
from django.conf import settings
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import django_audit_fields.fields.hostname_modification_field
import django_audit_fields.fields.userfield
import django_audit_fields.fields.uuid_auto_field
import django_audit_fields.models.audit_model_mixin
import django_revision.revision_field
import edc_crf.model_mixins.crf_status_model_mixin
import edc_model.models.fields.other_charfield
import edc_model.validators.date
import edc_protocol.validators
import edc_utils.date
import edc_visit_tracking.managers
import simple_history.models
import uuid


class Migration(migrations.Migration):
    dependencies = [
        ("sites", "0002_alter_domain_unique"),
        ("intecomm_lists", "0003_dmmanagement_dmmanagement_intecomm_li_id_b4d41f_idx"),
        migrations.swappable_dependency(settings.AUTH_USER_MODEL),
        ("intecomm_subject", "0004_historicalsocialharms_employment_impact_and_more"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsocialharms",
            name="coworkers_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="... with your coworkers?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsocialharms",
            name="employment_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="... with your employment?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsocialharms",
            name="family_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="... with your family?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsocialharms",
            name="friends_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="... with your friends?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsocialharms",
            name="healthcare_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="... with your healthcare?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsocialharms",
            name="insurance_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="... with your insurance?",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsocialharms",
            name="other_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="... with any other aspect of your life",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsocialharms",
            name="other_impact_description",
            field=models.CharField(
                blank=True, max_length=50, null=True, verbose_name="Please describe ..."
            ),
        ),
        migrations.AlterField(
            model_name="historicalsocialharms",
            name="other_service_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="... with any other health service",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsocialharms",
            name="other_service_impact_description",
            field=models.CharField(
                blank=True, max_length=50, null=True, verbose_name="Please describe ..."
            ),
        ),
        migrations.AlterField(
            model_name="socialharms",
            name="coworkers_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="... with your coworkers?",
            ),
        ),
        migrations.AlterField(
            model_name="socialharms",
            name="employment_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="... with your employment?",
            ),
        ),
        migrations.AlterField(
            model_name="socialharms",
            name="family_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="... with your family?",
            ),
        ),
        migrations.AlterField(
            model_name="socialharms",
            name="friends_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="... with your friends?",
            ),
        ),
        migrations.AlterField(
            model_name="socialharms",
            name="healthcare_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="... with your healthcare?",
            ),
        ),
        migrations.AlterField(
            model_name="socialharms",
            name="insurance_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="... with your insurance?",
            ),
        ),
        migrations.AlterField(
            model_name="socialharms",
            name="other_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="... with any other aspect of your life",
            ),
        ),
        migrations.AlterField(
            model_name="socialharms",
            name="other_impact_description",
            field=models.CharField(
                blank=True, max_length=50, null=True, verbose_name="Please describe ..."
            ),
        ),
        migrations.AlterField(
            model_name="socialharms",
            name="other_service_impact",
            field=models.CharField(
                choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                max_length=25,
                verbose_name="... with any other health service",
            ),
        ),
        migrations.AlterField(
            model_name="socialharms",
            name="other_service_impact_description",
            field=models.CharField(
                blank=True, max_length=50, null=True, verbose_name="Please describe ..."
            ),
        ),
        migrations.CreateModel(
            name="HistoricalHealthEconomics",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        db_index=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Report Date",
                    ),
                ),
                ("consent_model", models.CharField(editable=False, max_length=50, null=True)),
                (
                    "consent_version",
                    models.CharField(editable=False, max_length=10, null=True),
                ),
                (
                    "history_id",
                    models.UUIDField(
                        default=uuid.uuid4, editable=False, primary_key=True, serialize=False
                    ),
                ),
                (
                    "crf_status",
                    models.CharField(
                        choices=[
                            ("INCOMPLETE", "Incomplete (some data pending)"),
                            ("COMPLETE", "Complete"),
                        ],
                        default=edc_crf.model_mixins.crf_status_model_mixin.get_crf_status_default,
                        help_text="If some data is still pending, flag this CRF as incomplete",
                        max_length=25,
                        verbose_name="CRF status",
                    ),
                ),
                (
                    "crf_status_comments",
                    models.TextField(
                        blank=True,
                        help_text="for example, why some data is still pending",
                        null=True,
                        verbose_name="Any comments related to status of this CRF",
                    ),
                ),
                (
                    "occupation",
                    models.CharField(
                        max_length=50, verbose_name="What is your occupation/profession?"
                    ),
                ),
                (
                    "education_in_years",
                    models.IntegerField(
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(50),
                        ],
                        verbose_name="How many years of education did you complete?",
                    ),
                ),
                (
                    "education_certificate",
                    models.CharField(
                        blank=True,
                        max_length=50,
                        null=True,
                        verbose_name="What is your highest education certificate?",
                    ),
                ),
                (
                    "primary_school",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        max_length=15,
                        verbose_name="Did you go to primary/elementary school?",
                    ),
                ),
                (
                    "primary_school_in_years",
                    models.IntegerField(
                        blank=True,
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(10),
                        ],
                        verbose_name="If YES, for how many years",
                    ),
                ),
                (
                    "secondary_school",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        max_length=15,
                        verbose_name="Did you go to secondary school?",
                    ),
                ),
                (
                    "secondary_school_in_years",
                    models.IntegerField(
                        blank=True,
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(10),
                        ],
                        verbose_name="If YES, for how many years",
                    ),
                ),
                (
                    "higher_education",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        max_length=15,
                        verbose_name="Did you go to higher education?",
                    ),
                ),
                (
                    "higher_education_in_years",
                    models.IntegerField(
                        blank=True,
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(10),
                        ],
                        verbose_name="If YES, for how many years",
                    ),
                ),
                (
                    "welfare",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Do you receive any welfare or social service support",
                    ),
                ),
                (
                    "income_per_month",
                    models.IntegerField(
                        help_text="in local currency",
                        null=True,
                        verbose_name="How much do you earn (take home) per month?",
                    ),
                ),
                (
                    "household_income_per_month",
                    models.IntegerField(
                        help_text="in local currency",
                        null=True,
                        verbose_name="What is the total income in your household per month?",
                    ),
                ),
                (
                    "is_highest_earner",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        null=True,
                        verbose_name="Are you the person who earns the highest income in your household?",
                    ),
                ),
                (
                    "highest_earner",
                    models.CharField(
                        blank=True,
                        max_length=50,
                        null=True,
                        verbose_name="If NO, what is the profession of the person who earns the highest income?",
                    ),
                ),
                (
                    "food_per_month",
                    models.IntegerField(
                        help_text="in local currency",
                        null=True,
                        verbose_name="How much do you/your family spend on food in a month?",
                    ),
                ),
                (
                    "accomodation_per_month",
                    models.IntegerField(
                        help_text="in local currency",
                        null=True,
                        verbose_name="How much do you/your family spend on rent (or house loan/mortgage) and utilities in a month?",
                    ),
                ),
                (
                    "large_expenditure_year",
                    models.IntegerField(
                        help_text="e.g. furniture, electrical items, cars (in local currency)",
                        null=True,
                        verbose_name="How much have you spent on large items in the last year",
                    ),
                ),
                (
                    "received_rx_month",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        help_text="not including today",
                        max_length=15,
                        verbose_name="Over the last month, did you get any drugs on your visit to the health facility?",
                    ),
                ),
                (
                    "rx_dm_month",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        help_text="not including today",
                        max_length=15,
                        verbose_name="Did you receive drugs for raised blood sugar (diabetes) over the last month?",
                    ),
                ),
                (
                    "rx_dm_paid_month_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If `other pay source`, please specify ... (DM)",
                    ),
                ),
                (
                    "rx_dm_cost_month",
                    models.IntegerField(
                        blank=True,
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="If these drugs were not free, how much did you pay?",
                    ),
                ),
                (
                    "rx_htn_month",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        help_text="not including today",
                        max_length=15,
                        verbose_name="Did you receive drugs for raised blood pressure (hypertension) over the last month?",
                    ),
                ),
                (
                    "rx_htn_paid_month_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If `other pay source`, please specify ...(HTN)",
                    ),
                ),
                (
                    "rx_htn_cost_month",
                    models.IntegerField(
                        blank=True,
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="If these drugs were not free, how much did you pay?",
                    ),
                ),
                (
                    "rx_hiv_month",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        help_text="not including today",
                        max_length=15,
                        verbose_name="Did you receive anti-retroviral drugs for HIV over the last month?",
                    ),
                ),
                (
                    "rx_hiv_paid_month_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If `other pay source`, please specify ... (HIV)",
                    ),
                ),
                (
                    "rx_hiv_cost_month",
                    models.IntegerField(
                        blank=True,
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="If these drugs were not free, how much did you pay?",
                    ),
                ),
                (
                    "rx_other_month",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        max_length=15,
                        verbose_name="Did you receive any 'other' drugs?",
                    ),
                ),
                (
                    "rx_other_paid_month_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If `other pay source`, please specify ...",
                    ),
                ),
                (
                    "rx_other_cost_month",
                    models.IntegerField(
                        blank=True,
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="If not free, how much did you pay for these 'other' drugs?",
                    ),
                ),
                (
                    "non_drug_activities_month",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        null=True,
                        verbose_name="Over the last month, did you spend money on other activities (not drugs) relating to your health?",
                    ),
                ),
                (
                    "non_drug_activities_detail_month",
                    models.TextField(
                        blank=True, null=True, verbose_name="If YES, what was the activity"
                    ),
                ),
                (
                    "non_drug_activities_cost_month",
                    models.IntegerField(
                        blank=True,
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="If YES, how much was spent on other activities (not drugs) relating to your health?",
                    ),
                ),
                (
                    "healthcare_expenditure_total_month",
                    models.IntegerField(
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="How much in total has been spent on your healthcare in the last month?",
                    ),
                ),
                (
                    "missed_routine_activities",
                    models.CharField(
                        choices=[
                            ("working", "Working"),
                            ("studying", "Studying"),
                            ("caring_for_children", "Caring for children"),
                            ("house_maintenance", "House maintenance"),
                            ("nothing", "Nothing"),
                            ("OTHER", "Other, please specify"),
                        ],
                        max_length=25,
                        null=True,
                        verbose_name="What would you be doing if you had not come to the health facility today?",
                    ),
                ),
                (
                    "missed_routine_activities_other",
                    models.CharField(
                        blank=True,
                        max_length=50,
                        null=True,
                        verbose_name="If OTHER, please specify",
                    ),
                ),
                (
                    "off_work_days",
                    models.DecimalField(
                        decimal_places=1,
                        help_text="in days. (1,2,3 etc. If half-day 0.5)",
                        max_digits=4,
                        null=True,
                        verbose_name="How much time did you take off work?",
                    ),
                ),
                (
                    "travel_time",
                    models.CharField(
                        help_text="in hours and minutes (format HH:MM)",
                        max_length=5,
                        null=True,
                        verbose_name="How long did it take you to reach here?",
                    ),
                ),
                (
                    "hospital_time",
                    models.CharField(
                        help_text="in hours and minutes (format HH:MM)",
                        max_length=5,
                        null=True,
                        verbose_name="How much time did you spend at the health care facility?",
                    ),
                ),
                (
                    "lost_income",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        null=True,
                        verbose_name="Did you lose earnings as a result of coming here today? ",
                    ),
                ),
                (
                    "lost_income_amount",
                    models.IntegerField(
                        blank=True,
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="If Yes, how much did you lose?",
                    ),
                ),
                (
                    "childcare",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        null=True,
                        verbose_name="Did you ask anyone else, such as your family member/friend to look after your child/children in order to come here?",
                    ),
                ),
                (
                    "childcare_source",
                    models.CharField(
                        choices=[
                            ("N/A", "Not applicable"),
                            ("working", "Working"),
                            ("studying", "Studying"),
                            ("caring_for_children", "Caring for children"),
                            ("house_maintenance", "House maintenance"),
                            ("nothing", "Nothing"),
                            ("OTHER", "Other, specify"),
                        ],
                        default="N/A",
                        max_length=25,
                        null=True,
                        verbose_name="If Yes, what would they have been doing if they had not stayed to look after your child or children?",
                    ),
                ),
                (
                    "childcare_source_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "childcare_source_timeoff",
                    models.DecimalField(
                        blank=True,
                        decimal_places=1,
                        help_text="in days. (1,2,3 etc. If half-day 0.5)",
                        max_digits=4,
                        null=True,
                        verbose_name="How much time did a family member or friend take off?",
                    ),
                ),
                (
                    "transport_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If `other reason`, please specify ...",
                    ),
                ),
                (
                    "transport_cost",
                    models.IntegerField(
                        help_text="Coming to the health care facility going back home. (In local currency)",
                        null=True,
                        verbose_name="How much did you spend on transport in total?",
                    ),
                ),
                (
                    "food_cost",
                    models.IntegerField(
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="How much did you spend on food while you were at the health care faility today?",
                    ),
                ),
                (
                    "received_rx_today",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Did you get any drugs on your visit to the health facility today?",
                    ),
                ),
                (
                    "rx_dm_today",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        max_length=15,
                        verbose_name="Did you receive drugs for raised blood sugar (diabetes) today?",
                    ),
                ),
                (
                    "rx_dm_paid_today_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If `other pay source`, please specify ...",
                    ),
                ),
                (
                    "rx_dm_cost_today",
                    models.IntegerField(
                        blank=True,
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="If not free, how much did you pay for raised blood sugar (diabetes) drugs?",
                    ),
                ),
                (
                    "rx_htn_today",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        max_length=15,
                        verbose_name="Did you receive raised blood pressure (hypertension) drugs today?",
                    ),
                ),
                (
                    "rx_htn_paid_today_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If `other pay source`, please specify ...",
                    ),
                ),
                (
                    "rx_htn_cost_today",
                    models.IntegerField(
                        blank=True,
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="If not free, how much did you pay for high blood pressure (Hypertension) drugs?",
                    ),
                ),
                (
                    "rx_hiv_today",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        max_length=15,
                        verbose_name="Did you receive ARVs (HIV) today?",
                    ),
                ),
                (
                    "rx_hiv_paid_today_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If `other pay source`, please specify ...",
                    ),
                ),
                (
                    "rx_hiv_cost_today",
                    models.IntegerField(
                        blank=True,
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="If not free, how much did you pay for ARV (HIV) drugs?",
                    ),
                ),
                (
                    "rx_other_today",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        max_length=15,
                        verbose_name="Did you receive 'other' drugs today?",
                    ),
                ),
                (
                    "rx_other_paid_today_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If `other pay source`, please specify ...",
                    ),
                ),
                (
                    "rx_other_cost_today",
                    models.IntegerField(
                        blank=True,
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="If not free, how much did you pay for these 'other' drugs?",
                    ),
                ),
                (
                    "non_drug_activities_today",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        null=True,
                        verbose_name="Did you spend money on other activities (not drugs) relating to your health today?",
                    ),
                ),
                (
                    "non_drug_activities_detail_today",
                    models.TextField(
                        blank=True, null=True, verbose_name="If YES, what was the activity"
                    ),
                ),
                (
                    "non_drug_activities_cost_today",
                    models.IntegerField(
                        blank=True,
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="If YES, how much did you spend?",
                    ),
                ),
                (
                    "healthcare_expenditure_total_month_today",
                    models.IntegerField(
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="How much in total has been spent on your healthcare in the last month?",
                    ),
                ),
                (
                    "finance_by_sale",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        null=True,
                        verbose_name="Do you sell anything to pay for your visit today?",
                    ),
                ),
                (
                    "finance_by_loan",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        null=True,
                        verbose_name="Did you take any loans to pay for your visit?",
                    ),
                ),
                (
                    "health_insurance",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Do you have private healthcare insurance?",
                    ),
                ),
                (
                    "health_insurance_cost",
                    models.IntegerField(
                        blank=True,
                        help_text="in local currency",
                        null=True,
                        verbose_name="If Yes, how much do you pay towards your contributions to healthcare insurance every month?",
                    ),
                ),
                (
                    "patient_club",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Do you contribute to a patient club?",
                    ),
                ),
                (
                    "patient_club_cost",
                    models.IntegerField(
                        blank=True,
                        help_text="in local currency",
                        null=True,
                        verbose_name="If Yes, how much do you pay towards your contributions to the patient club every month?",
                    ),
                ),
                ("history_date", models.DateTimeField(db_index=True)),
                ("history_change_reason", models.CharField(max_length=100, null=True)),
                (
                    "history_type",
                    models.CharField(
                        choices=[("+", "Created"), ("~", "Changed"), ("-", "Deleted")],
                        max_length=1,
                    ),
                ),
                (
                    "history_user",
                    models.ForeignKey(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.AUTH_USER_MODEL,
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
                (
                    "subject_visit",
                    models.ForeignKey(
                        blank=True,
                        db_constraint=False,
                        null=True,
                        on_delete=django.db.models.deletion.DO_NOTHING,
                        related_name="+",
                        to="intecomm_subject.subjectvisit",
                    ),
                ),
            ],
            options={
                "verbose_name": "historical Health Economics (Rev 1)",
                "verbose_name_plural": "historical Health Economics (Rev 1)",
                "ordering": ("-history_date", "-history_id"),
                "get_latest_by": ("history_date", "history_id"),
            },
            bases=(simple_history.models.HistoricalChanges, models.Model),
        ),
        migrations.CreateModel(
            name="HealthEconomics",
            fields=[
                (
                    "revision",
                    django_revision.revision_field.RevisionField(
                        blank=True,
                        editable=False,
                        help_text="System field. Git repository tag:branch:commit.",
                        max_length=75,
                        null=True,
                        verbose_name="Revision",
                    ),
                ),
                (
                    "created",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "modified",
                    models.DateTimeField(
                        blank=True, default=django_audit_fields.models.audit_model_mixin.utcnow
                    ),
                ),
                (
                    "user_created",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user created",
                    ),
                ),
                (
                    "user_modified",
                    django_audit_fields.fields.userfield.UserField(
                        blank=True,
                        help_text="Updated by admin.save_model",
                        max_length=50,
                        verbose_name="user modified",
                    ),
                ),
                (
                    "hostname_created",
                    models.CharField(
                        blank=True,
                        default=_socket.gethostname,
                        help_text="System field. (modified on create only)",
                        max_length=60,
                    ),
                ),
                (
                    "hostname_modified",
                    django_audit_fields.fields.hostname_modification_field.HostnameModificationField(
                        blank=True,
                        help_text="System field. (modified on every save)",
                        max_length=50,
                    ),
                ),
                ("device_created", models.CharField(blank=True, max_length=10)),
                ("device_modified", models.CharField(blank=True, max_length=10)),
                (
                    "id",
                    django_audit_fields.fields.uuid_auto_field.UUIDAutoField(
                        blank=True,
                        editable=False,
                        help_text="System auto field. UUID primary key.",
                        primary_key=True,
                        serialize=False,
                    ),
                ),
                (
                    "report_datetime",
                    models.DateTimeField(
                        default=edc_utils.date.get_utcnow,
                        help_text="If reporting today, use today's date/time, otherwise use the date/time this information was reported.",
                        validators=[
                            edc_protocol.validators.datetime_not_before_study_start,
                            edc_model.validators.date.datetime_not_future,
                        ],
                        verbose_name="Report Date",
                    ),
                ),
                ("consent_model", models.CharField(editable=False, max_length=50, null=True)),
                (
                    "consent_version",
                    models.CharField(editable=False, max_length=10, null=True),
                ),
                (
                    "crf_status",
                    models.CharField(
                        choices=[
                            ("INCOMPLETE", "Incomplete (some data pending)"),
                            ("COMPLETE", "Complete"),
                        ],
                        default=edc_crf.model_mixins.crf_status_model_mixin.get_crf_status_default,
                        help_text="If some data is still pending, flag this CRF as incomplete",
                        max_length=25,
                        verbose_name="CRF status",
                    ),
                ),
                (
                    "crf_status_comments",
                    models.TextField(
                        blank=True,
                        help_text="for example, why some data is still pending",
                        null=True,
                        verbose_name="Any comments related to status of this CRF",
                    ),
                ),
                (
                    "occupation",
                    models.CharField(
                        max_length=50, verbose_name="What is your occupation/profession?"
                    ),
                ),
                (
                    "education_in_years",
                    models.IntegerField(
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(50),
                        ],
                        verbose_name="How many years of education did you complete?",
                    ),
                ),
                (
                    "education_certificate",
                    models.CharField(
                        blank=True,
                        max_length=50,
                        null=True,
                        verbose_name="What is your highest education certificate?",
                    ),
                ),
                (
                    "primary_school",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        max_length=15,
                        verbose_name="Did you go to primary/elementary school?",
                    ),
                ),
                (
                    "primary_school_in_years",
                    models.IntegerField(
                        blank=True,
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(10),
                        ],
                        verbose_name="If YES, for how many years",
                    ),
                ),
                (
                    "secondary_school",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        max_length=15,
                        verbose_name="Did you go to secondary school?",
                    ),
                ),
                (
                    "secondary_school_in_years",
                    models.IntegerField(
                        blank=True,
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(10),
                        ],
                        verbose_name="If YES, for how many years",
                    ),
                ),
                (
                    "higher_education",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        max_length=15,
                        verbose_name="Did you go to higher education?",
                    ),
                ),
                (
                    "higher_education_in_years",
                    models.IntegerField(
                        blank=True,
                        null=True,
                        validators=[
                            django.core.validators.MinValueValidator(0),
                            django.core.validators.MaxValueValidator(10),
                        ],
                        verbose_name="If YES, for how many years",
                    ),
                ),
                (
                    "welfare",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Do you receive any welfare or social service support",
                    ),
                ),
                (
                    "income_per_month",
                    models.IntegerField(
                        help_text="in local currency",
                        null=True,
                        verbose_name="How much do you earn (take home) per month?",
                    ),
                ),
                (
                    "household_income_per_month",
                    models.IntegerField(
                        help_text="in local currency",
                        null=True,
                        verbose_name="What is the total income in your household per month?",
                    ),
                ),
                (
                    "is_highest_earner",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        null=True,
                        verbose_name="Are you the person who earns the highest income in your household?",
                    ),
                ),
                (
                    "highest_earner",
                    models.CharField(
                        blank=True,
                        max_length=50,
                        null=True,
                        verbose_name="If NO, what is the profession of the person who earns the highest income?",
                    ),
                ),
                (
                    "food_per_month",
                    models.IntegerField(
                        help_text="in local currency",
                        null=True,
                        verbose_name="How much do you/your family spend on food in a month?",
                    ),
                ),
                (
                    "accomodation_per_month",
                    models.IntegerField(
                        help_text="in local currency",
                        null=True,
                        verbose_name="How much do you/your family spend on rent (or house loan/mortgage) and utilities in a month?",
                    ),
                ),
                (
                    "large_expenditure_year",
                    models.IntegerField(
                        help_text="e.g. furniture, electrical items, cars (in local currency)",
                        null=True,
                        verbose_name="How much have you spent on large items in the last year",
                    ),
                ),
                (
                    "received_rx_month",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        help_text="not including today",
                        max_length=15,
                        verbose_name="Over the last month, did you get any drugs on your visit to the health facility?",
                    ),
                ),
                (
                    "rx_dm_month",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        help_text="not including today",
                        max_length=15,
                        verbose_name="Did you receive drugs for raised blood sugar (diabetes) over the last month?",
                    ),
                ),
                (
                    "rx_dm_paid_month_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If `other pay source`, please specify ... (DM)",
                    ),
                ),
                (
                    "rx_dm_cost_month",
                    models.IntegerField(
                        blank=True,
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="If these drugs were not free, how much did you pay?",
                    ),
                ),
                (
                    "rx_htn_month",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        help_text="not including today",
                        max_length=15,
                        verbose_name="Did you receive drugs for raised blood pressure (hypertension) over the last month?",
                    ),
                ),
                (
                    "rx_htn_paid_month_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If `other pay source`, please specify ...(HTN)",
                    ),
                ),
                (
                    "rx_htn_cost_month",
                    models.IntegerField(
                        blank=True,
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="If these drugs were not free, how much did you pay?",
                    ),
                ),
                (
                    "rx_hiv_month",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        help_text="not including today",
                        max_length=15,
                        verbose_name="Did you receive anti-retroviral drugs for HIV over the last month?",
                    ),
                ),
                (
                    "rx_hiv_paid_month_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If `other pay source`, please specify ... (HIV)",
                    ),
                ),
                (
                    "rx_hiv_cost_month",
                    models.IntegerField(
                        blank=True,
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="If these drugs were not free, how much did you pay?",
                    ),
                ),
                (
                    "rx_other_month",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        max_length=15,
                        verbose_name="Did you receive any 'other' drugs?",
                    ),
                ),
                (
                    "rx_other_paid_month_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If `other pay source`, please specify ...",
                    ),
                ),
                (
                    "rx_other_cost_month",
                    models.IntegerField(
                        blank=True,
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="If not free, how much did you pay for these 'other' drugs?",
                    ),
                ),
                (
                    "non_drug_activities_month",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        null=True,
                        verbose_name="Over the last month, did you spend money on other activities (not drugs) relating to your health?",
                    ),
                ),
                (
                    "non_drug_activities_detail_month",
                    models.TextField(
                        blank=True, null=True, verbose_name="If YES, what was the activity"
                    ),
                ),
                (
                    "non_drug_activities_cost_month",
                    models.IntegerField(
                        blank=True,
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="If YES, how much was spent on other activities (not drugs) relating to your health?",
                    ),
                ),
                (
                    "healthcare_expenditure_total_month",
                    models.IntegerField(
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="How much in total has been spent on your healthcare in the last month?",
                    ),
                ),
                (
                    "missed_routine_activities",
                    models.CharField(
                        choices=[
                            ("working", "Working"),
                            ("studying", "Studying"),
                            ("caring_for_children", "Caring for children"),
                            ("house_maintenance", "House maintenance"),
                            ("nothing", "Nothing"),
                            ("OTHER", "Other, please specify"),
                        ],
                        max_length=25,
                        null=True,
                        verbose_name="What would you be doing if you had not come to the health facility today?",
                    ),
                ),
                (
                    "missed_routine_activities_other",
                    models.CharField(
                        blank=True,
                        max_length=50,
                        null=True,
                        verbose_name="If OTHER, please specify",
                    ),
                ),
                (
                    "off_work_days",
                    models.DecimalField(
                        decimal_places=1,
                        help_text="in days. (1,2,3 etc. If half-day 0.5)",
                        max_digits=4,
                        null=True,
                        verbose_name="How much time did you take off work?",
                    ),
                ),
                (
                    "travel_time",
                    models.CharField(
                        help_text="in hours and minutes (format HH:MM)",
                        max_length=5,
                        null=True,
                        verbose_name="How long did it take you to reach here?",
                    ),
                ),
                (
                    "hospital_time",
                    models.CharField(
                        help_text="in hours and minutes (format HH:MM)",
                        max_length=5,
                        null=True,
                        verbose_name="How much time did you spend at the health care facility?",
                    ),
                ),
                (
                    "lost_income",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        null=True,
                        verbose_name="Did you lose earnings as a result of coming here today? ",
                    ),
                ),
                (
                    "lost_income_amount",
                    models.IntegerField(
                        blank=True,
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="If Yes, how much did you lose?",
                    ),
                ),
                (
                    "childcare",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        null=True,
                        verbose_name="Did you ask anyone else, such as your family member/friend to look after your child/children in order to come here?",
                    ),
                ),
                (
                    "childcare_source",
                    models.CharField(
                        choices=[
                            ("N/A", "Not applicable"),
                            ("working", "Working"),
                            ("studying", "Studying"),
                            ("caring_for_children", "Caring for children"),
                            ("house_maintenance", "House maintenance"),
                            ("nothing", "Nothing"),
                            ("OTHER", "Other, specify"),
                        ],
                        default="N/A",
                        max_length=25,
                        null=True,
                        verbose_name="If Yes, what would they have been doing if they had not stayed to look after your child or children?",
                    ),
                ),
                (
                    "childcare_source_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If other, please specify ...",
                    ),
                ),
                (
                    "childcare_source_timeoff",
                    models.DecimalField(
                        blank=True,
                        decimal_places=1,
                        help_text="in days. (1,2,3 etc. If half-day 0.5)",
                        max_digits=4,
                        null=True,
                        verbose_name="How much time did a family member or friend take off?",
                    ),
                ),
                (
                    "transport_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If `other reason`, please specify ...",
                    ),
                ),
                (
                    "transport_cost",
                    models.IntegerField(
                        help_text="Coming to the health care facility going back home. (In local currency)",
                        null=True,
                        verbose_name="How much did you spend on transport in total?",
                    ),
                ),
                (
                    "food_cost",
                    models.IntegerField(
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="How much did you spend on food while you were at the health care faility today?",
                    ),
                ),
                (
                    "received_rx_today",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Did you get any drugs on your visit to the health facility today?",
                    ),
                ),
                (
                    "rx_dm_today",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        max_length=15,
                        verbose_name="Did you receive drugs for raised blood sugar (diabetes) today?",
                    ),
                ),
                (
                    "rx_dm_paid_today_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If `other pay source`, please specify ...",
                    ),
                ),
                (
                    "rx_dm_cost_today",
                    models.IntegerField(
                        blank=True,
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="If not free, how much did you pay for raised blood sugar (diabetes) drugs?",
                    ),
                ),
                (
                    "rx_htn_today",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        max_length=15,
                        verbose_name="Did you receive raised blood pressure (hypertension) drugs today?",
                    ),
                ),
                (
                    "rx_htn_paid_today_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If `other pay source`, please specify ...",
                    ),
                ),
                (
                    "rx_htn_cost_today",
                    models.IntegerField(
                        blank=True,
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="If not free, how much did you pay for high blood pressure (Hypertension) drugs?",
                    ),
                ),
                (
                    "rx_hiv_today",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        max_length=15,
                        verbose_name="Did you receive ARVs (HIV) today?",
                    ),
                ),
                (
                    "rx_hiv_paid_today_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If `other pay source`, please specify ...",
                    ),
                ),
                (
                    "rx_hiv_cost_today",
                    models.IntegerField(
                        blank=True,
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="If not free, how much did you pay for ARV (HIV) drugs?",
                    ),
                ),
                (
                    "rx_other_today",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No"), ("N/A", "Not applicable")],
                        default="N/A",
                        max_length=15,
                        verbose_name="Did you receive 'other' drugs today?",
                    ),
                ),
                (
                    "rx_other_paid_today_other",
                    edc_model.models.fields.other_charfield.OtherCharField(
                        blank=True,
                        max_length=35,
                        null=True,
                        verbose_name="If `other pay source`, please specify ...",
                    ),
                ),
                (
                    "rx_other_cost_today",
                    models.IntegerField(
                        blank=True,
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="If not free, how much did you pay for these 'other' drugs?",
                    ),
                ),
                (
                    "non_drug_activities_today",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        null=True,
                        verbose_name="Did you spend money on other activities (not drugs) relating to your health today?",
                    ),
                ),
                (
                    "non_drug_activities_detail_today",
                    models.TextField(
                        blank=True, null=True, verbose_name="If YES, what was the activity"
                    ),
                ),
                (
                    "non_drug_activities_cost_today",
                    models.IntegerField(
                        blank=True,
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="If YES, how much did you spend?",
                    ),
                ),
                (
                    "healthcare_expenditure_total_month_today",
                    models.IntegerField(
                        help_text="In local currency",
                        null=True,
                        validators=[django.core.validators.MinValueValidator(0)],
                        verbose_name="How much in total has been spent on your healthcare in the last month?",
                    ),
                ),
                (
                    "finance_by_sale",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        null=True,
                        verbose_name="Do you sell anything to pay for your visit today?",
                    ),
                ),
                (
                    "finance_by_loan",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        null=True,
                        verbose_name="Did you take any loans to pay for your visit?",
                    ),
                ),
                (
                    "health_insurance",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Do you have private healthcare insurance?",
                    ),
                ),
                (
                    "health_insurance_cost",
                    models.IntegerField(
                        blank=True,
                        help_text="in local currency",
                        null=True,
                        verbose_name="If Yes, how much do you pay towards your contributions to healthcare insurance every month?",
                    ),
                ),
                (
                    "patient_club",
                    models.CharField(
                        choices=[("Yes", "Yes"), ("No", "No")],
                        max_length=15,
                        verbose_name="Do you contribute to a patient club?",
                    ),
                ),
                (
                    "patient_club_cost",
                    models.IntegerField(
                        blank=True,
                        help_text="in local currency",
                        null=True,
                        verbose_name="If Yes, how much do you pay towards your contributions to the patient club every month?",
                    ),
                ),
                (
                    "rx_dm_paid_month",
                    models.ManyToManyField(
                        blank=True,
                        related_name="+",
                        to="intecomm_lists.drugpaysources",
                        verbose_name="If YES, how were these paid for?",
                    ),
                ),
                (
                    "rx_dm_paid_today",
                    models.ManyToManyField(
                        blank=True,
                        related_name="+",
                        to="intecomm_lists.drugpaysources",
                        verbose_name="If YES, received raised blood sugar (diabetes) drugs, how were these paid for?",
                    ),
                ),
                (
                    "rx_hiv_paid_month",
                    models.ManyToManyField(
                        blank=True,
                        max_length=25,
                        related_name="+",
                        to="intecomm_lists.drugpaysources",
                        verbose_name="If YES, how were these paid for?",
                    ),
                ),
                (
                    "rx_hiv_paid_today",
                    models.ManyToManyField(
                        blank=True,
                        max_length=25,
                        related_name="+",
                        to="intecomm_lists.drugpaysources",
                        verbose_name="If YES, received ARV (HIV) drugs, how were these paid for?",
                    ),
                ),
                (
                    "rx_htn_paid_month",
                    models.ManyToManyField(
                        blank=True,
                        related_name="+",
                        to="intecomm_lists.drugpaysources",
                        verbose_name="If YES, how were these paid for?",
                    ),
                ),
                (
                    "rx_htn_paid_today",
                    models.ManyToManyField(
                        blank=True,
                        related_name="+",
                        to="intecomm_lists.drugpaysources",
                        verbose_name="If YES, received high blood pressure (Hypertension) drugs, how were these paid for?",
                    ),
                ),
                (
                    "rx_other_paid_month",
                    models.ManyToManyField(
                        blank=True,
                        related_name="+",
                        to="intecomm_lists.drugpaysources",
                        verbose_name="If YES, received 'other' drugs, how were these paid for?",
                    ),
                ),
                (
                    "rx_other_paid_today",
                    models.ManyToManyField(
                        blank=True,
                        related_name="+",
                        to="intecomm_lists.drugpaysources",
                        verbose_name="If YES, received 'other' drugs, how were these paid for?",
                    ),
                ),
                (
                    "site",
                    models.ForeignKey(
                        editable=False,
                        null=True,
                        on_delete=django.db.models.deletion.PROTECT,
                        related_name="+",
                        to="sites.site",
                    ),
                ),
                (
                    "subject_visit",
                    models.OneToOneField(
                        on_delete=django.db.models.deletion.PROTECT,
                        to="intecomm_subject.subjectvisit",
                    ),
                ),
                (
                    "transport",
                    models.ManyToManyField(
                        max_length=25,
                        to="intecomm_lists.transportchoices",
                        verbose_name="Which form of transport did you take to get to the hospital today?",
                    ),
                ),
            ],
            options={
                "verbose_name": "Health Economics (Rev 1)",
                "verbose_name_plural": "Health Economics (Rev 1)",
                "ordering": ("-modified", "-created"),
                "get_latest_by": "modified",
                "abstract": False,
                "default_permissions": ("add", "change", "delete", "view", "export", "import"),
            },
            managers=[
                ("on_site", edc_visit_tracking.managers.CrfCurrentSiteManager()),
                ("objects", edc_visit_tracking.managers.CrfModelManager()),
            ],
        ),
        migrations.AddIndex(
            model_name="healtheconomics",
            index=models.Index(
                fields=["subject_visit", "site", "id"], name="intecomm_su_subject_0fa533_idx"
            ),
        ),
        migrations.AddIndex(
            model_name="healtheconomics",
            index=models.Index(
                fields=["subject_visit", "report_datetime"],
                name="intecomm_su_subject_10dc95_idx",
            ),
        ),
    ]



from django.apps import AppConfig as DjangoAppConfig


class AppConfig(DjangoAppConfig):
    name = "intecomm_reports"
    verbose_name = "INTECOMM Reports"
    include_in_administration_section = True



from __future__ import annotations

import re
from dataclasses import dataclass, field
from datetime import timedelta


@dataclass
class Duration:
    duration_str: str
    hrs: int = field(default=0)
    mins: int = field(default=0)
    hm_pattern: str = field(default=r"^([0-9]{1,3}h([0-5]?[0-9]m))$", init=False)
    h_pattern: str = field(default=r"^([0-9]{1,3}h)$", init=False)
    m_pattern: str = field(default=r"^([0-5]?[0-9]m)$", init=False)
    timedelta: timedelta = field(default=timedelta(hours=0, minutes=0), init=False)

    def __post_init__(self):
        if re.match(self.hm_pattern, self.duration_str):
            h, m = self.duration_str.split("h")
            self.hrs = int(h)
            self.mins = int(m.split("m")[0])
        elif re.match(self.h_pattern, self.duration_str):
            h = self.duration_str.split("h")[0]
            self.hrs = int(h)
        elif re.match(self.m_pattern, self.duration_str):
            m = self.duration_str.split("m")[0]
            self.mins = int(m)
        else:
            raise ValueError()
        self.timedelta = timedelta(hours=self.hrs, minutes=self.mins)



# Generated by Django 4.2.11 on 2024-05-22 21:30

from django.db import migrations, models
import edc_model.validators.date
import edc_protocol.validators
import edc_utils.date


class Migration(migrations.Migration):

    dependencies = [
        ("intecomm_screening", "0070_alter_patientlog_conditions"),
    ]

    operations = [
        migrations.AlterField(
            model_name="historicalsubjectscreening",
            name="report_datetime",
            field=models.DateTimeField(
                default=edc_utils.date.get_utcnow,
                help_text="Date and time of report.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date and Time",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreeningtz",
            name="report_datetime",
            field=models.DateTimeField(
                default=edc_utils.date.get_utcnow,
                help_text="Date and time of report.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date and Time",
            ),
        ),
        migrations.AlterField(
            model_name="historicalsubjectscreeningug",
            name="report_datetime",
            field=models.DateTimeField(
                default=edc_utils.date.get_utcnow,
                help_text="Date and time of report.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date and Time",
            ),
        ),
        migrations.AlterField(
            model_name="subjectscreening",
            name="report_datetime",
            field=models.DateTimeField(
                default=edc_utils.date.get_utcnow,
                help_text="Date and time of report.",
                validators=[
                    edc_protocol.validators.datetime_not_before_study_start,
                    edc_model.validators.date.datetime_not_future,
                ],
                verbose_name="Report Date and Time",
            ),
        ),
    ]



from edc_action_item.action_with_notification import ActionWithNotification
from edc_action_item.exceptions import ActionError
from edc_action_item.site_action_items import site_action_items
from edc_adverse_event.constants import DEATH_REPORT_ACTION
from edc_constants.constants import HIGH_PRIORITY
from edc_locator.action_items import SubjectLocatorAction as BaseSubjectLocatorAction
from edc_ltfu.constants import LTFU_ACTION
from edc_offstudy.constants import END_OF_STUDY_ACTION
from edc_protocol_incident.action_items import (
    ProtocolIncidentAction as BaseProtocolIncidentAction,
)
from edc_transfer.action_items import SubjectTransferAction as BaseSubjectTransferAction
from edc_transfer.constants import SUBJECT_TRANSFER_ACTION
from intecomm_rando.constants import COMMUNITY_ARM, FACILITY_ARM

from intecomm_group.utils import get_assignment_for_patient_group
from intecomm_screening.models import PatientLog
from intecomm_subject.constants import MISSED_VISIT_ACTION

from .constants import OFFSCHEDULE_COMM_ACTION, OFFSCHEDULE_INTE_ACTION

site_action_items.unregister(BaseSubjectLocatorAction)


class SubjectLocatorAction(BaseSubjectLocatorAction):
    reference_model = "intecomm_prn.subjectlocator"
    admin_site_name = "intecomm_prn_admin"


# TODO: action item for end of study does not show
class OffscheduleInteAction(ActionWithNotification):
    name = OFFSCHEDULE_INTE_ACTION
    display_name = "Submit Off-Schedule (Facility)"
    notification_display_name = "Off-Schedule (Facility)"
    parent_action_names = [
        DEATH_REPORT_ACTION,
        LTFU_ACTION,
        SUBJECT_TRANSFER_ACTION,
    ]
    reference_model = "intecomm_prn.offscheduleinte"
    show_link_to_changelist = True
    admin_site_name = "intecomm_prn_admin"
    priority = HIGH_PRIORITY
    singleton = True
    next_actions = [END_OF_STUDY_ACTION]


class OffscheduleCommAction(ActionWithNotification):
    name = OFFSCHEDULE_COMM_ACTION
    display_name = "Submit Off-Schedule (Community)"
    notification_display_name = "Off-Schedule (Community)"
    parent_action_names = [
        DEATH_REPORT_ACTION,
        LTFU_ACTION,
        SUBJECT_TRANSFER_ACTION,
    ]
    reference_model = "intecomm_prn.offschedulecomm"
    show_link_to_changelist = True
    admin_site_name = "intecomm_prn_admin"
    priority = HIGH_PRIORITY
    singleton = True
    next_actions = [END_OF_STUDY_ACTION]


class EndOfStudyAction(ActionWithNotification):
    name = END_OF_STUDY_ACTION
    display_name = "Submit End of Study Report"
    notification_display_name = "End of Study Report"
    parent_action_names = [OFFSCHEDULE_INTE_ACTION, OFFSCHEDULE_COMM_ACTION]
    reference_model = "intecomm_prn.endofstudy"
    show_link_to_changelist = True
    admin_site_name = "intecomm_prn_admin"
    priority = HIGH_PRIORITY
    singleton = True


class LossToFollowupAction(ActionWithNotification):
    name = LTFU_ACTION
    display_name = "Submit Loss to Follow Up Report"
    notification_display_name = " Loss to Follow Up Report"
    parent_action_names = [MISSED_VISIT_ACTION]
    reference_model = "intecomm_prn.losstofollowup"
    show_link_to_changelist = True
    show_link_to_add = True
    admin_site_name = "intecomm_prn_admin"
    priority = HIGH_PRIORITY
    singleton = True


class SubjectTransferAction(BaseSubjectTransferAction):
    reference_model = "intecomm_prn.subjecttransfer"
    admin_site_name = "intecomm_prn_admin"

    def get_next_actions(self):
        patient_log = PatientLog.objects.get(
            subject_identifier=self.reference_obj.subject_identifier
        )
        assignment = get_assignment_for_patient_group(
            patient_log.group_identifier,
        )
        if assignment == COMMUNITY_ARM:
            next_actions = [OFFSCHEDULE_COMM_ACTION]
        elif assignment == FACILITY_ARM:
            next_actions = [OFFSCHEDULE_INTE_ACTION]
        else:
            raise ActionError(
                f"Unable to determine assignment. Got {self.reference_obj.subject_identifier}"
            )
        return next_actions


class ProtocolIncidentAction(BaseProtocolIncidentAction):
    reference_model = "intecomm_prn.protocolincident"
    admin_site_name = "intecomm_prn_admin"


site_action_items.register(EndOfStudyAction)
site_action_items.register(LossToFollowupAction)
site_action_items.register(OffscheduleInteAction)
site_action_items.register(OffscheduleCommAction)
site_action_items.register(ProtocolIncidentAction)
site_action_items.register(SubjectTransferAction)
site_action_items.register(SubjectLocatorAction)
